import React, { useState, useEffect } from 'react';
import styles from './index.less';
import { Row, Col, Image } from 'antd';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import { EyeFilled } from '@ant-design/icons';

const col = { xs: 24, sm: 12, md: 8, lg: 6, xl: 6, xxl: 4 };

function Insert() {
  const { data, loading } = useRequest(async () => {
    let zizhi = await doFetch({ url: '/honor/list', params: { type: '1' } });
    let honer = await doFetch({ url: '/honor/list', params: { type: '2' } });
    let hangye = await doFetch({ url: '/honor/list', params: { type: '3' } });
    let zhishi = await doFetch({ url: '/honor/list', params: { type: '4' } });
    return {
      zizhi: zizhi?.data?.dataList,
      honer: honer?.data?.dataList,
      hangye: hangye?.data?.dataList,
      zhishi: zhishi?.data?.dataList,
    };
  });

  return (
    <div>
      <div className="section">
        <h2
          style={{
            textAlign: 'center',
            marginBottom: '2rem',
            fontSize: '1.2rem',
          }}
        >
          企业资质
        </h2>
        <Image.PreviewGroup>
          <Row gutter={20}>
            {data?.zizhi?.map((it, i) => {
              return (
                <Col {...col} className={styles?.item}>
                  <Image
                    preview={{
                      mask: (
                        <>
                          <EyeFilled></EyeFilled> &nbsp;预览
                        </>
                      ),
                    }}
                    src={it.picUrl}
                    alt=""
                  />
                  <div className={styles?.title}>{it?.name}</div>
                </Col>
              );
            })}
          </Row>
        </Image.PreviewGroup>
      </div>

      <div className="section">
        <h2
          style={{
            textAlign: 'center',
            margin: '2rem 0 1.2rem 0',
            fontSize: '1.2rem',
          }}
        >
          行业担当
        </h2>
        <Image.PreviewGroup>
          <Row gutter={20}>
            {data?.hangye?.map((it, i) => {
              return (
                <Col {...col} className={styles?.item}>
                  <Image
                    preview={{
                      mask: (
                        <>
                          <EyeFilled></EyeFilled> &nbsp;预览
                        </>
                      ),
                    }}
                    src={it.picUrl}
                    alt=""
                  />
                  <div className={styles?.title}>{it?.name}</div>
                </Col>
              );
            })}
          </Row>
        </Image.PreviewGroup>
      </div>

      <div className="section">
        <h2
          style={{
            textAlign: 'center',
            margin: '2rem 0 1.2rem 0',
            fontSize: `1.2rem`,
          }}
        >
          政府荣誉
        </h2>
        <Image.PreviewGroup>
          <Row gutter={20}>
            {data?.honer?.map((it, i) => {
              return (
                <Col {...col} className={styles?.item}>
                  <Image
                    preview={{
                      mask: (
                        <>
                          <EyeFilled></EyeFilled> &nbsp;预览
                        </>
                      ),
                    }}
                    src={it.picUrl}
                    alt=""
                  />
                  <div className={styles?.title}>{it?.name}</div>
                </Col>
              );
            })}
          </Row>
        </Image.PreviewGroup>
      </div>

      <div className="section">
        <h2
          style={{
            textAlign: 'center',
            margin: '2rem 0 1.2rem 0',
            fontSize: '1.2rem',
          }}
        >
          知识产权
        </h2>
        <Image.PreviewGroup>
          <Row gutter={20}>
            {data?.zhishi?.map((it, i) => {
              return (
                <Col {...col} className={styles?.item}>
                  <Image
                    preview={{
                      mask: (
                        <>
                          <EyeFilled></EyeFilled> &nbsp;预览
                        </>
                      ),
                    }}
                    src={it.picUrl}
                    alt=""
                  />
                  <div className={styles?.title}>{it?.name}</div>
                </Col>
              );
            })}
          </Row>
        </Image.PreviewGroup>
      </div>
    </div>
  );
}

export default Insert;
