import React, { useState, useEffect } from 'react';
import styles from './index.less';
import { Row, Col, Image, Pagination, Card, Tag, Grid } from 'antd';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import { EyeFilled } from '@ant-design/icons';
import { history } from 'umi';
const { useBreakpoint } = Grid;

const col = { xs: 24, sm: 12, md: 12, lg: 8, xl: 8, xxl: 6 };
const { Meta } = Card;

function Join({ location: { query } }) {
  const [curid, setcurid] = useState(query.id);

  const { data, loading } = useRequest(async () => {
    let data = await doFetch({
      url: '/recruit/detail',
      params: { id: curid },
    });
    return data?.data?.data;
  });

  return (
    <div className="container">
      <div className="section">
        <h2 className="title">岗位详情</h2>
        <p style={{ textAlign: 'center', fontSize: '0.6rem' }}>
          如果您对我们感兴趣，欢迎投递简历至
          <a href="mailto:chenjie@jsnangao.com" target="_blank">
            chenjie@jsnangao.com
          </a>
          ，邮件主题格式：<a>岗位名称+姓名+学校+学历，</a>更多招聘信息请详询：
          <a href="tel:025-52187179">025-52187179</a>，期待您的加入！
        </p>
        <div className="tags">
          <p
            style={{
              fontSize: '1rem',
              width: '100%',
              marginTop: '1rem',
              textAlign: 'center',
            }}
          >
            <span>{data?.positionName}</span>
            <span
              style={{ color: 'rgba(255, 103, 47, 1)', paddingLeft: '1.5rem' }}
            >
              {data?.salary}
            </span>
          </p>
          <div className="center">
            {data?.positionDepartment && (
              <Tag
                color="blue"
                style={{ fontSize: '0.6rem', padding: '0.2rem' }}
              >
                {data?.positionDepartment}
              </Tag>
            )}
            {data?.education && (
              <Tag
                color="cyan"
                style={{ fontSize: '0.6rem', padding: '0.2rem' }}
              >
                {data?.education}
              </Tag>
            )}
            {data?.wordExperience && (
              <Tag
                color="geekblue"
                style={{ fontSize: '0.6rem', padding: '0.2rem' }}
              >
                {data?.wordExperience}
              </Tag>
            )}
            {data?.hiringNum && (
              <Tag style={{ fontSize: '0.6rem', padding: '0.2rem' }}>
                招聘：{data?.hiringNum}人
              </Tag>
            )}
          </div>
          <div className="center" style={{ marginTop: '1rem' }}>
            {data?.workAddress && (
              <Tag style={{ fontSize: '0.6rem', padding: '0.2rem' }}>
                地点：{data?.workAddress}
              </Tag>
            )}
          </div>
        </div>
        <div
          style={{
            fontSize: '1rem',
            fontWeight: 'bolder',
            marginTop: '2rem',
            textAlign: 'center',
          }}
        >
          岗位职责
        </div>
        <div
          style={{
            backgroundColor: '#ffffff',
            fontSize: '0.6rem',
            margin: '0 auto',
            minWidth: 360,
            padding: '1rem 2rem',
          }}
          dangerouslySetInnerHTML={{ __html: data?.responsibilities }}
        ></div>
        <div
          style={{
            fontSize: '1rem',
            fontWeight: 'bolder',
            marginTop: '2rem',
            textAlign: 'center',
          }}
        >
          任职要求
        </div>
        <div
          style={{
            backgroundColor: '#ffffff',
            fontSize: '0.6rem',
            margin: '0 auto',
            minWidth: 360,
            padding: '1rem 2rem',
          }}
          dangerouslySetInnerHTML={{ __html: data?.jobRequirements }}
        ></div>
        <div
          style={{
            fontSize: '1rem',
            fontWeight: 'bolder',
            marginTop: '2rem',
            textAlign: 'center',
          }}
        >
          福利待遇
        </div>
        <div
          style={{
            backgroundColor: '#ffffff',
            fontSize: '0.6rem',
            margin: '0 auto',
            minWidth: 360,
            padding: '1rem 2rem',
          }}
          dangerouslySetInnerHTML={{ __html: data?.welfareTreatment }}
        ></div>
      </div>
    </div>
  );
}

export default Join;
