import React, { useState, useEffect } from 'react';
import styles from './index.less';
import { Row, Col, Image, Pagination, Card } from 'antd';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import { EyeFilled } from '@ant-design/icons';
import { history } from 'umi';

const col = { xs: 24, sm: 12, md: 12, lg: 8, xl: 8, xxl: 6 };
const { Meta } = Card;

function Insert() {
  const [page, setpage] = useState({ pageIndex: 1, pageSize: 10 });
  const [total, settotal] = useState();
  const { data, loading } = useRequest(
    async () => {
      let data = await doFetch({
        url: '/realTimeInfo/page',
        params: page,
      });
      settotal(data?.data?.page?.total);
      return data?.data?.page?.records;
    },
    {
      refreshDeps: [page],
    },
  );

  const onChange = (pageIndex, pageSize) => {
    setpage({
      pageIndex,
      pageSize,
    });
  };

  return (
    <div className="sections">
      <Row gutter={24}>
        {data?.map?.((it, i) => {
          return (
            <Col {...col} style={{ marginBottom: 24 }}>
              <Card
                hoverable
                bordered={false}
                style={{
                  width: '100%',
                }}
                cover={
                  <div
                    style={{
                      backgroundImage: `url(${it?.picUrl})`,
                      height: '288px',
                    }}
                    className="img"
                  />
                }
                onClick={() => {
                  history.push({
                    pathname: '/about/newsdetail',
                    query: {
                      id: it.id,
                    },
                  });
                }}
              >
                <Meta
                  title={
                    <span style={{ fontSize: '0.8rem' }}>{it?.title}</span>
                  }
                  description={
                    <span style={{ fontSize: '0.6rem' }}>
                      {it?.releaseTime}
                    </span>
                  }
                />
              </Card>
            </Col>
          );
        })}
      </Row>

      <div className="center">
        <Pagination
          current={page?.pageIndex}
          showQuickJumper
          total={total}
          onChange={onChange}
          showTotal={(total, range) =>
            `${total} 条中的 ${range[0]}-${range[1]}`
          }
        />
      </div>
    </div>
  );
}

export default Insert;
