import React, { useState, useEffect } from 'react';
import styles from './index.less';
import { Row, Col, Image, Pagination, Card, Divider } from 'antd';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import { EyeFilled } from '@ant-design/icons';
import { history } from 'umi';

const col = { xs: 24, sm: 12, md: 12, lg: 8, xl: 8, xxl: 6 };
const { Meta } = Card;

function Insert({ location: { query } }) {
  const [curid, setcurid] = useState(query.id);

  const { data, loading } = useRequest(
    async () => {
      let data = await doFetch({
        url: '/realTimeInfo/detail',
        params: { id: curid },
      });
      return data?.data?.data;
    },
    {
      refreshDeps: [curid],
    },
  );

  const prev = useRequest(
    async () => {
      let data = await doFetch({
        url: '/realTimeInfo/getRealTimePrevAndNext',
        params: { id: curid },
      });
      return data?.data?.data;
    },
    {
      refreshDeps: [curid],
    },
  );

  return (
    <div className="section">
      <h2 className="title">{data?.title}</h2>
      <p style={{ textAlign: 'center', fontSize: '0.6rem' }}>
        {data?.releaseTime}
      </p>
      <div
        dangerouslySetInnerHTML={{ __html: data?.informationContent }}
        style={{ fontSize: '0.6rem' }}
        className="html"
      ></div>
      <Divider></Divider>
      <p
        className="hoverable"
        onClick={() => {
          prev?.data?.prev?.id && setcurid(prev?.data?.prev?.id);
        }}
      >
        上一篇:{' '}
        {prev?.data?.prev?.title ?? (
          <span style={{ color: '#999999' }}>已是第一篇</span>
        )}
      </p>
      <p
        className="hoverable"
        onClick={() => {
          prev?.data?.next?.id && setcurid(prev?.data?.next?.id);
        }}
      >
        下一篇: {prev?.data?.next?.title ?? '已是最后一篇'}
      </p>
    </div>
  );
}

export default Insert;
